import { NodeExecuteInputs, NodeInfo, NodeInstance } from './node.instance';
import { NodeContext } from './node.context';
import { NodeExecutorConfig, NodeExecutorPipeline, NodeExecutorPipelineInterface, NodeExecutorStepInterface, PipelineAddNodeResults, PipelineExecuteResults, PipelineNode } from './node.type';
export declare class NodeExecutor {
    #private;
    config?: NodeExecutorConfig | undefined;
    private nodeId;
    private nodeInfos;
    protected executedNodes: Map<number, NodeInstance>;
    protected pipelineNodes: Array<PipelineNode>;
    protected pipelines: Map<string, NodeExecutorPipeline>;
    protected defaultPipeline?: NodeExecutorPipeline;
    protected cache: Map<string, PipelineAddNodeResults>;
    pipeline: NodeExecutorPipelineInterface;
    step: NodeExecutorStepInterface;
    constructor(config?: NodeExecutorConfig | undefined);
    /**
     * register nodes batch
     * @param nodeInfos the node info list
     */
    registerNodes(nodeInfos: Record<string, NodeInfo>): void;
    /**
     * register one node
     * @param nodeName node name
     * @param nodeInfo node info
     */
    registerNode(nodeName: string, nodeInfo: NodeInfo): void;
    getRegisteredNodes(): Record<string, NodeInfo>;
    registerPipeline(type: string, pipeline: NodeExecutorPipeline, asDefault?: boolean): void;
    /**
     * create one node instance from node name
     * @param name
     */
    createNodeInstance(name: string): NodeInstance;
    /**
     * execute one node and wait it finish
     * @param nodeNameOrInstance node name or node instance
     * @param inputs execute inputs
     */
    executeNode(nodeNameOrInstance: NodeInstance | string, inputs?: NodeExecuteInputs): Promise<NodeContext<any>>;
    /**
     * add one node to the pipeline
     * @param nodeNameOrInstance node name or node instance
     * @param inputs execute inputs
     * @param withCache with cache
     */
    addNode(nodeNameOrInstance: NodeInstance | string, inputs?: NodeExecuteInputs, withCache?: boolean): PipelineAddNodeResults;
    /**
     * clear all nodes added before
     */
    clearNodes(): void;
    /**
     * execute the nodes in the pipeline
     */
    execute(): Promise<PipelineExecuteResults>;
    dumpPipeline(): Record<string, any>;
    /**
     * get executed node instances
     */
    getExecutedNodes(): NodeInstance[];
    private executePipeline;
    /**
     * start a new session
     */
    newSession(): Promise<void[] | undefined>;
    protected _createPipelineProxy(): NodeExecutorPipelineInterface;
    protected _createStepProxy(): NodeExecutorStepInterface;
    log(level: 'debug' | 'info' | 'trace' | 'warn' | 'error', message: any): void;
}
