import { NodeContext, NodeContextOutput } from './node.context';
import { NodeExecutor } from './node.executor';
type NodeInfoValueType = 'float' | 'int' | 'boolean' | 'string' | 'enum' | 'output' | string;
type NodeExecuteInputValue = number | boolean | string | [string, number] | NodeContextOutput;
export type NodeExecuteOutputValue = number | boolean | string;
interface NodeInputOutputInfo {
    name: string;
    type: NodeInfoValueType;
    description?: string;
}
export interface NodeInputInfo extends NodeInputOutputInfo {
    required?: boolean;
    min?: number;
    max?: number;
    default?: any;
    enums?: string[];
    enumStrictCheck?: boolean;
}
export interface NodeOutputInfo extends NodeInputOutputInfo {
}
export type NodeExecuteInputs = Record<string, NodeExecuteInputValue>;
export type NodeExecuteOutputs = Record<string, NodeExecuteOutputValue>;
export type NodeExecuteFunction = (node: NodeInstance, inputs?: NodeExecuteInputs) => Promise<NodeExecuteOutputs>;
export interface NodeInfo {
    inputs: NodeInputInfo[];
    outputs: NodeOutputInfo[];
    executeFunction: NodeExecuteFunction;
    pipelineType?: string;
    description?: string;
    category?: string;
    output?: boolean;
    [key: string]: any;
}
export declare class NodeInstance {
    private executor;
    readonly name: string;
    readonly id: number;
    readonly nodeInfo: NodeInfo;
    private executeFunction?;
    executeInputs?: NodeExecuteInputs;
    constructor(executor: NodeExecutor, name: string, id: number, nodeInfo: NodeInfo, executeFunction?: NodeExecuteFunction | undefined);
    execute(inputs?: NodeExecuteInputs): Promise<NodeContext<{
        [x: string]: any;
    }>>;
    onExecute(inputs?: NodeExecuteInputs): Promise<NodeExecuteOutputs>;
    validInputs(inputs?: NodeExecuteInputs): NodeExecuteInputs;
    private validInput;
}
export {};
