import { NodeContext, NodeContextOutput } from './node.context';
import { NodeExecuteInputs, NodeInstance } from './node.instance';
export interface NodeExecutorConfig {
    /**
     * Whether to ignore inputs validate when node before execute
     */
    ignoreInputsValidate?: boolean;
    /**
     * Whether to strict check input connection value
     */
    inputConnectionStrictCheck?: boolean;
    /**
     * Whether to strict check enum value
     */
    enumStrictCheck?: boolean;
    /**
     * Whether to use debug model, will log more
     */
    debug?: boolean;
    /**
     * logger fn
     * @param level
     * @param message
     */
    logger?: (level: 'debug' | 'info' | 'log' | 'trace' | 'warn' | 'error', message: string) => void;
}
export interface NodeExecRequest {
    name: string;
    params?: Record<string, any>;
}
export interface DistinctType<Name> {
    __DISTINCT__: Name;
}
export interface PipelineNode {
    nodeInstance: NodeInstance;
    executeInputs?: NodeExecuteInputs;
}
export type PipelineAddNodeResults = Record<string, NodeContextOutput> & {
    /**
     * node id
     */
    _id: number;
};
export type PipelineExecuteResults = Record<string, NodeContextOutput>;
export interface NodeExecutorPipeline {
    onExecute: (pipelineNodes: PipelineNode[]) => Promise<PipelineExecuteResults>;
    onNewSession: () => Promise<void>;
    dump: (pipelineNodes: PipelineNode[]) => Record<string, any>;
}
type JSONValue = string | number | boolean | {
    [x: string]: JSONValue;
} | Array<JSONValue>;
export interface NodeExecutorPipelineInterface {
    /**
     * dump the pipeline to string
     */
    dump(): JSONValue;
    /**
     * clear all nodes added before
     */
    clear(): void;
    /**
     * execute the pipeline
     */
    execute(): Promise<PipelineExecuteResults>;
}
export interface NodeExecutorStepInterface {
}
type ToContextOutputs<Outputs> = {
    [name in keyof Outputs]: NodeContextOutput<Outputs[name]>;
};
type ToOutputsType<T> = T extends NodeContext<infer Outputs> ? ToContextOutputs<Outputs> : void;
export type ToPipelineInterface<T extends Record<string, (...args: any) => any>> = {
    [k in keyof T]: (inputs: Parameters<T[k]>) => ToOutputsType<ReturnType<T[k]>>;
};
export type ToStepInterface<T extends Record<string, (...args: any) => any>> = {
    [k in keyof T]: (...args: Parameters<T[k]>) => Promise<ReturnType<T[k]>>;
};
export {};
